/* Hardcode User Agent */
pref("general.useragent.override", "Mozilla/5.0 (X11; Linux x86_64 rv:118.0.2) Gecko/20100101 Firefox/118.0.2");

/* Hardcode region */
pref("browser.search.region", "US");

/* Pin recommended addons */
pref("browser.newtabpage.pinned", "[{\"url\":\"https://addons.mozilla.org/en-US/firefox/addon/ublock-origin/\",\"label\":\"uBlock Origin\"},{\"url\":\"https://addons.mozilla.org/en-US/firefox/addon/https-everywhere/?src=search\",\"label\":\"HTTPS Everywhere\"},{\"url\":\"https://addons.mozilla.org/ru/firefox/addon/noscript/\",\"label\":\"NoScript\"},{\"url\":\"https://addons.mozilla.org/ru/firefox/addon/multi-account-containers/\",\"label\":\"Firefox Multi-Account Containers\"}]");

/* Disable SHA-1 except for certificates issued by non-built-in CAs */
pref("security.pki.sha1_enforcement_level", 1);

/* Disable the 3DES cipher */
pref("security.ssl3.rsa_des_ede3_sha", false);
pref("security.ssl3.dhe_rsa_aes_128_sha", false);
pref("security.ssl3.ecdhe_ecdsa_aes_128_gcm_sha256", false);
pref("security.ssl3.ecdhe_ecdsa_aes_128_sha", false);
pref("security.ssl3.ecdhe_rsa_aes_128_sha", false);
pref("security.ssl3.rsa_des_ede3_sha", false);

/* Require Safe Negotiation */
pref("security.ssl.require_safe_negotiation", true);
pref("security.ssl.treat_unsafe_negotiation_as_broken", true);

/* Disable Session Identifiers */
pref("security.ssl.disable_session_identifiers", true);

/* Disable TLS False Start */
pref("security.ssl.enable_false_start", false);

/* Disable TLS versions 1.0 and 1.1 */
pref("security.tls.version.min", 3);

/* Disable 0-RTT - Zero Round Trip Time Resumption (0-RTT) is a feature that is new in TLS 1.3 */
pref("security.tls.enable_0rtt_data", false);

/* Disable Automatic Formfill */
pref("browser.formfill.enable", false);

/* Never store extra session data. */
pref("browser.sessionstore.privacy_level", 2);

/* Disable All Disk Caching */
pref("browser.cache.disk.enable", false);
pref("browser.cache.disk_cache_ssl", false);
pref("browser.cache.memory.enable", false);
pref("browser.cache.offline.enable", false);
pref("browser.cache.insecure.enable", false);

/* Disable document's fonts */
pref("browser.display.use_document_fonts", 0);

/* Disable automatic check for updates to search plugins. */
pref("browser.search.update", false);

/*
 * When you download an application file, Firefox will verify its signature.
 * If it is signed, Firefox then compares the signature with a list of known
 * safe publishers. For files that are not identified by the lists
 * as "safe" (allowed) or as "malware" (blocked), Firefox asks Google's Safe
 * Browsing service if the software is safe by sending it some of the download's
 * metadata.
 */
pref("browser.safebrowsing.downloads.remote.enabled", false);

/*
 * Firefox keeps track of a list of malware to compare against data the user
 * downloads. In the event the user downloads known malware, a warning can
 * be displayed. This preference determines whether to enable these malware
 * checks.
 */
pref("browser.safebrowsing.malware.enabled", false);

/*
 * Tracking Protection is a new platform-level technology that blocks HTTP
 * loads at the network level. It is based on the Safe Browsing technology
 * that powers our phishing and malware protection.
 *
 * Disable tracking protection.
 */
pref("privacy.trackingprotection.enabled", false);
pref("privacy.trackingprotection.annotate_channels", false);
pref("privacy.trackingprotection.cryptomining.enabled", false);
pref("privacy.trackingprotection.fingerprinting.enabled", false);
pref("privacy.trackingprotection.lower_network_priority", false);
pref("privacy.trackingprotection.origin_telemetry.enabled", false);
pref("privacy.trackingprotection.pbmode.enabled", false);
pref("privacy.trackingprotection.socialtracking.enabled", false);

/*
 * Firefox's captive portal feature tests whether your network connection
 * requires logging in, for example, on a public wi-fi hotspot, by regularly
 * connecting to http://detectportal.firefox.com/success.txt
 */
pref("network.captive-portal-service.enabled", false);

/*
 * Firefox may be updating its blocklist, which is used to block malicious
 * extensions, vulnerable plugins, revoked certificates and graphics drivers
 * known to cause crashes.
 */
pref("extensions.blocklist.enabled", false);

/*
 * The network predictor (formerly called 'seer') makes preemptive
 * connections to resources in a page based on cached information. It can
 * also do the same when the user hovers over a link.
 */
pref("network.predictor.enabled", false);

/* Disable DNS Prefetching */
pref("network.dns.disableprefetch", false);

/* Disable Network Prefetching */
pref("network.prefetch-next", false);

/*
 * To improve the loading speed, Firefox will open predictive connections
 * to sites when the user hovers their mouse over thumbnails on the New Tab Page
 * or the user starts to search in the Search Bar, or in the search field
 * on the Home or the New Tab Page. In case the user follows through with
 * the action, the page can begin loading faster since some of the work was
 * already started in advance.
 */
pref("network.http.speculative-parallel-limit", 0);

/*
 * If you use the built-in default homepage about:home, Firefox will show
 * some Mozilla related content around the search box ("Snippets"), which
 * is updated once a day.
 */
pref("browser.aboutHomeSnippets.updateUrl", "");

/*
 * After a browser update, Firefox might show an additional tab next to your
 * usual homepage to offer more information on changes or new features included
 * in the update.
 */
pref("browser.startup.homepage_override.mstone", "ignore");

/*
 * The Add-ons manager displays information about each add-on you have installed
 * and provides personalized recommendations in the Get Add-ons panel. To keep
 * this data updated, Firefox will request information from the Mozilla Add-ons
 * gallery once a day
 */
pref("extensions.getAddons.cache.enabled", false);

/*
 * The availability of automatic installation is controlled by the
 * extensions.autoDisableScopes preference and behavior are defined by the
 * following values:
 *
 * 1  - The current user’s profile.
 * 2  - All profiles of the logged-in user.
 * 4  - Installed and owned by Firefox.
 * 8  - Installed for all users of the computer.
 *
 * By default, extensions.autoDisableScopes is set to 15 so that automatic
 * installs are disabled from all locations. To disable only a subset of
 * locations, set the preference to the sum of the values for the locations you
 * want to disable. For example, 3 will disable “The current user’s profile.”
 * and “All profiles of the logged-in user.” Setting the value to 0 disables
 * this feature and means all add-ons will be installed without user
 * confirmation.
 */
pref("extensions.autoDisableScopes", 0);

/*
 * In some circumstances, you may want Firefox to ignore some or all of the
 * additional install locations listed above. In this case, use the preference
 * extensions.enabledScopes. By default, this preference is not included in the
 * standard downloads of Firefox, so will need to be added.
 */
pref("extensions.enabledScopes", 15);

/*
 * Mozilla will ask a small sample of users to rate their experience with
 * Firefox to get a better insight into the sentiment about the browser. For
 * more information about this see
 * https://wiki.mozilla.org/Advocacy/heartbeat. The rating feature will
 * establish a connection to Mozilla's servers at startup.
 */
pref("app.normandy.enabled", false);

/*
 * Firefox contains a "Send Video To Device" feature that is disabled by
 * default, to send HTML5 video content to a Roku, Chromecast or similar
 * device in the same network. When this feature is enabled, Firefox will
 * send SSDP packages (Simple Service Discovery Protocol, multicast address
 * 239.255.255.250, port 1900) to the local network, to discover and pair
 * with such a device. This can trigger a firewall dialog asking you if you
 * want to allow such connections.
 */
pref("browser.casting.enabled", false);

/* Disable CDM playback */
pref("media.gmp-widevinecdm.enabled", false);
pref("media.gmp-widevinecdm.visible", false);

/* Disable ALL Telemetry Features */
pref("browser.newtabpage.activity-stream.feeds.telemetry", false);
pref("browser.newtabpage.activity-stream.telemetry", false);
pref("browser.pingcentre.telemetry", false);
pref("devtools.onboarding.telemetry-logged", false);
pref("media.wmf.deblacklisting-for-telemetry-in-gpu-process", false);
pref("toolkit.telemetry.enabled", false);
pref("toolkit.telemetry.archive.enabled", false);
pref("toolkit.telemetry.bhrping.enabled", false);
pref("toolkit.telemetry.firstshutdownping.enabled", false);
pref("toolkit.telemetry.hybridcontent.enabled", false);
pref("toolkit.telemetry.newprofileping.enabled", false);
pref("toolkit.telemetry.unified", false);
pref("toolkit.telemetry.updateping.enabled", false);
pref("toolkit.telemetry.shutdownpingsender.enabled", false);
pref("toolkit.telemetry.server", "");

/* Disable Health Reporting */
pref("datareporting.healthreport.uploadEnabled",false);
pref("datareporting.healthreport.service.enabled",false);

/* Disable Firefox Account */
pref("identity.fxaccounts.enabled", false);
pref("identity.fxaccounts.toolbar.enabled", false);

/* Disable Geolocation Services */
pref("geo.enabled", false);
pref("geo.wifi.uri", "");
pref("browser.search.geoip.url", "");

/* Disable Plugin Scanning */
pref("plugin.scan.plid.all", false);

/* Disable HTTP Referral Headers */
pref("network.http.sendRefererHeader", 0);
pref("network.http.referer.XOriginPolicy", 0);

/* Disable referrer headers between https websites. */
pref("network.http.sendSecureXSiteReferrer", false);

/* Enable encrypted SNI */
pref("network.security.esni.enabled", true);

/* Allow cookies from originating server only */
pref("network.cookie.cookieBehavior", 1);

/* Enable Fingerprint Resistance */
pref("privacy.resistfingerprinting", true);

/* Defines which sets of data get cleared when Firefox shuts down */
pref("privacy.clearOnShutdown.cache", true);
pref("privacy.clearOnShutdown.cookies", true);
pref("privacy.clearOnShutdown.downloads", true);
pref("privacy.clearOnShutdown.formdata", true);
pref("privacy.clearOnShutdown.history", true);
pref("privacy.clearOnShutdown.offlineApps", true);
pref("privacy.clearOnShutdown.sessions", true);

/*
 * Enable the Do Not Track header which informs websites and services
 * about the tracking preference
 */
pref("privacy.donottrackheader.enabled", true);

/* Disable Pocket extension */
pref("browser.pocket.enabled", false);
pref("extensions.pocket.enabled", false);
pref("extensions.pocket.api", "");
pref("extensions.pocket.site", "");
pref("extensions.pocket.oAuthConsumerKey", "");

/* Disable WebRTC */
pref("media.peerconnection.enabled", false);

/* Disable the Social features */
pref("social.active", false);
pref("social.enabled", false);

/* Disable Firefox sync */
pref("services.sync.autoconnect", false);
pref("services.sync.globalScore", 0);
pref("services.sync.engine.addons", false);
pref("services.sync.engine.addresses", false);
pref("services.sync.engine.bookmarks", false);
pref("services.sync.engine.creditcards", false);
pref("services.sync.engine.history", false);
pref("services.sync.engine.passwords", false);
pref("services.sync.engine.prefs", false);
pref("services.sync.engine.tabs", false);

/* Disable WebGL  */
pref("webgl.disabled", true);

/* Disable Battery API */
pref("dom.battery.enabled", false);

/* Enable First-Party Isolation */
pref("privacy.firstparty.isolate", true);

/* Disable send data to servers when leaving pages */
pref("beacon.enabled", false);

/* Disable remote debuging */
pref("devtools.debugger.remote-enabled", false);

/* Disable remote */
pref("remote.enabled", false);

/*
 * Disable search suggestions
 *
 * See https://firefox-source-docs.mozilla.org/browser/urlbar/preferences.html
 */
pref("browser.search.suggest.enabled", false);
pref("browser.urlbar.quicksuggest.enabled", false);
pref("browser.urlbar.quicksuggest.remoteSettings.enabled", false);
pref("browser.urlbar.suggest.quicksuggest.sponsored", false);
pref("browser.urlbar.suggest.quicksuggest.nonsponsored", false);

/*
 * A service to provide address bar suggestions to Firefox. Some of this content
 * comes from third parties. In this case, Merino serves as a privacy preserving
 * buffer.
 *
 * See https://mozilla-services.github.io/merino/
 */
pref("browser.urlbar.merino.enabled", false);
pref("browser.urlbar.merino.providers", "");

/*
 * The Web Applications 1.0 specification (also known as HTML5) defines a
 * new attribute for <a> elements: ping. This attribute contains one or more
 * URIs to "ping" (send a POST request to) when the user clicks the link.
 * The attribute would be useful for letting websites track visitors'
 * clicks.
 */
pref("browser.send_pings", false);

/* Disable extension updates in Firefox */
pref("extensions.update.enabled", false);

/* Disable obsolete plugins */
pref("plugin.state.flash", 0);
pref("plugin.state.java", 0);

/*
 * IDN support allows users to enter domain names containing extended
 * characters that aren’t supported in “standard” URLs. This makes it
 * possible for international websites to register domain names using
 * characters native to local languages.
 *
 * In order to expand the number of characters allowable in domain names to
 * include all Unicode characters, a type of encoding called “Punycode” was
 * developed. This encoding uses legal characters in domain names—dashes,
 * letters, and numbers—to represent Unicode characters. When IDN support is
 * enabled, Mozilla recognizes domain names encoded this way and converts
 * them into Unicode strings. Thus, a domain name that looks like
 * http://xn--tdali-d8a8w.lv/ is converted into a domain name that looks
 * like http://tūdaliņ.lv.
 *
 * Display the "raw", punycode version of internationalized domain names.
 */
pref("network.IDN_show_punycode", true);
pref("network.standard-url.punycode-host", true);

/*
 * Remove tracking from URLs
 */
pref("privacy.query_stripping.enabled", true);
pref("privacy.query_stripping.enabled.pbmode", true);

/*
 * This controls if we will do the query string stripping for redirects.
 */
pref("privacy.query_stripping.redirect", true);
